@@ -1,7 +1,7 @@
 package Complete::Fish::Gen::FromGetoptLong;
 
-our $DATE = '2016-10-22'; # DATE
-our $VERSION = '0.06'; # VERSION
+our $DATE = '2016-10-27'; # DATE
+our $VERSION = '0.07'; # VERSION
 
 use 5.010001;
 use strict;
@@ -101,6 +101,8 @@ $SPEC{gen_fish_complete_from_getopt_long_script} = {
     summary => 'Generate fish completion script from Getopt::Long script',
     description => <<'_',
 
+This routine generate fish `complete` command for each short/long option,
+enabling fish to display the options in a different color.
 
 _
     args => {
@@ -108,6 +110,7 @@ _
             schema => 'filename*',
             req => 1,
             pos => 0,
+            cmdline_aliases => {f=>{}},
         },
         cmdname => {
             summary => 'Command name to be completed, defaults to filename',
@@ -117,6 +120,10 @@ _
             summary => 'Completer name',
             schema => 'str*',
         },
+        skip_detect => {
+            schema => ['bool', is=>1],
+            cmdline_aliases => {D=>{}},
+        },
     },
     result => {
         schema => 'str*',
@@ -132,6 +139,7 @@ sub gen_fish_complete_from_getopt_long_script {
     require Getopt::Long::Dump;
     my $dump_res = Getopt::Long::Dump::dump_getopt_long_script(
         filename => $filename,
+        skip_detect => $args{skip_detect},
     );
     return $dump_res unless $dump_res->[0] == 200;
 
@@ -172,7 +180,7 @@ Complete::Fish::Gen::FromGetoptLong - Generate fish completion script from Getop
 
 =head1 VERSION
 
-This document describes version 0.06 of Complete::Fish::Gen::FromGetoptLong (from Perl distribution Complete-Fish-Gen-FromGetoptLong), released on 2016-10-22.
+This document describes version 0.07 of Complete::Fish::Gen::FromGetoptLong (from Perl distribution Complete-Fish-Gen-FromGetoptLong), released on 2016-10-27.
 
 =head1 SYNOPSIS
 
@@ -183,6 +191,9 @@ This document describes version 0.06 of Complete::Fish::Gen::FromGetoptLong (fro
 
 Generate fish completion script from Getopt::Long script.
 
+This routine generate fish C<complete> command for each short/long option,
+enabling fish to display the options in a different color.
+
 This function is not exported by default, but exportable.
 
 Arguments ('*' denotes required arguments):
@@ -199,6 +210,8 @@ Completer name.
 
 =item * B<filename>* => I<filename>
 
+=item * B<skip_detect> => I<bool>
+
 =back
 
 Returns an enveloped result (an array).
